# _*_ coding:utf-8 _*_
from setuptools import setup

setup(
	name='wsrLab-demo',
	version='0.3',
	author='wsr',
	author_email='702183233@qq.com',
	url='http://www.x.com',
	description="这是一个测试文件，用户PyPi测试！",
	packages=['wsrLab-demo'],
	zip_safe=False
)
